netapp_ontap.models.svm_s3_service API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.svm_s3_service`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SvmS3ServiceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SvmS3Service object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `certificate GET POST PATCH`

    The certificate field of the svm_s3_service.

  `enabled GET POST PATCH`

    Specifies whether or not to enable S3. Setting this value to true creates a service if one is not yet created.

  `is_http_enabled GET POST PATCH`

    Specifies whether HTTP is enabled on the S3 server. By default, HTTP is disabled on the S3 server.

  `is_https_enabled GET POST PATCH`

    Specifies whether HTTPS is enabled on the S3 server. By default, HTTPS is enabled on the S3 server.

  `links GET`

    The links field of the svm_s3_service.

  `name GET POST PATCH`

    Specifies the name of the S3 server. A server name length can range from 1 to 253 characters and can only contain the following combination of characters 0-9, A-Z, a-z, ".", and "-".

    Example: s3-server-1

  `port GET POST PATCH`

    Specifies the HTTP listener port for the S3 server. By default, HTTP is enabled on port 80.

  `secure_port GET POST PATCH`

    Specifies the HTTPS listener port for the S3 server. By default, HTTPS is enabled on port 443.